@@ -2,6 +2,8 @@ package Test::Smoke::App::Options;
 use warnings;
 use strict;
 
+our $VERSION = '0.001';
+
 use Test::Smoke::App::AppOption;
 
 =head1 NAME
@@ -16,7 +18,7 @@ my $opt = 'Test::Smoke::App::AppOption';
 sub synctree_config { # synctree.pl
     return (
         main_options => [
-            syncer(),
+            sync_type(),
         ],
         general_options => [
             ddir(),
@@ -130,6 +132,10 @@ sub reporter_config { # needed for sending out reports
             skip_tests(),
             harnessonly(),
             harness3opts(),
+            hostname(),
+            from(),
+            send_log(),
+            send_out(),
             user_note(),
             un_file(),
             un_position(),
@@ -186,6 +192,7 @@ sub runsmoke_config { # runsmoke.pl
             opt_continue(),
             skip_tests(),
             testmake(),
+            w32args(),
             w32cc(),
             w32make(),
         ],
@@ -361,7 +368,7 @@ sub from {
 }
 
 sub fsync { # How to sync the mdir for Forest.
-    my $s = syncer();
+    my $s = sync_type();
     $s->name('fsync');
     return $s;
 }
@@ -462,6 +469,15 @@ sub hdir { # hdir => ddir
     );
 }
 
+sub hostname {
+    return $opt->new(
+        name => 'hostname',
+        option => '=s',
+        deafult => undef,
+        helptext => 'Use the hostname option to override System::Info->hostname',
+    );
+}
+
 sub is56x {
     return $opt->new(
         name => 'is56x',
@@ -695,6 +711,7 @@ sub send_log {
         name => 'send_log',
         option => '=s',
         default => 'on_fail',
+        allow => [qw/ never on_fail always /],
         helptext => "Send logfile to the CoreSmokeDB server.",
     );
 }
@@ -704,6 +721,7 @@ sub send_out {
         name => 'send_out',
         option => '=s',
         default => 'never',
+        allow => [qw/ never on_fail always /],
         helptext => "Send out-file to the CoreSmokeDB server.",
     );
 }
@@ -765,7 +783,7 @@ sub smokedb_url {
     return $opt->new(
         name => 'smokedb_url',
         option => '=s',
-        default => 'http://perl5.test-smoke.org/report',
+        default => 'https://perl5.test-smoke.org/report',
         helptext => "The URL for sending reports to CoreSmokeDB.",
     );
 }
@@ -779,9 +797,9 @@ sub sync {
     );
 }
 
-sub syncer {
+sub sync_type {
     return $opt->new(
-        name     => 'syncer',
+        name     => 'sync_type',
         option   => '=s',
         allow    => [qw/git rsync copy/],
         default  => 'git',
